summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2020-05-03 01:18:06 +0200
committerSlávek Banko <slavek.banko@axis.cz>2020-05-07 14:37:03 +0200
commite8a95f169ebebc7d4aa0350cb059f8e5b0fcb018 (patch)
tree4f7a7909f31e79d34c7626d2b386659feba1f37f
parent9138b8f339759751c22d5ddfcd4d644d3a4ed021 (diff)
downloadtde-cmake-e8a95f16.tar.gz
tde-cmake-e8a95f16.zip
tde_create_translated_desktop: Allow spaces around the equal sign.
Signed-off-by: Slávek Banko <slavek.banko@axis.cz>
-rw-r--r--modules/TDEL10n.cmake4
-rw-r--r--modules/TDEMacros.cmake15
2 files changed, 9 insertions, 10 deletions
diff --git a/modules/TDEL10n.cmake b/modules/TDEL10n.cmake
index 9a6053f..1f7df76 100644
--- a/modules/TDEL10n.cmake
+++ b/modules/TDEL10n.cmake
@@ -1253,9 +1253,9 @@ function( tde_l10n_prepare_desktop )
math( EXPR _desktop_pos "${_desktop_pos}+1" )
# process line
- if( "${_desktop_line}" MATCHES "^${_keywords_match}=" )
+ if( "${_desktop_line}" MATCHES "^${_keywords_match}[ ]*=" )
string( REGEX REPLACE "\\\"" "\\\\\"" _desktop_line "${_desktop_line}" )
- string( REGEX REPLACE "^${_keywords_match}=([^\n]*)" "/*\\1*/i18n(\"\\2\");" _desktop_line "${_desktop_line}" )
+ string( REGEX REPLACE "^${_keywords_match}[ ]*=[ ]*([^\n]*)" "/*\\1*/i18n(\"\\2\");" _desktop_line "${_desktop_line}" )
else( )
set( _desktop_line "" )
endif( )
diff --git a/modules/TDEMacros.cmake b/modules/TDEMacros.cmake
index 92e54c3..fc82267 100644
--- a/modules/TDEMacros.cmake
+++ b/modules/TDEMacros.cmake
@@ -1735,7 +1735,7 @@ macro( tde_create_translated_desktop )
# create template for intltool-merge
file( READ ${_src} _src_data )
string( REPLACE ";" "|" _keywords_match "(${_keywords_desktop})" )
- string( REGEX REPLACE "(^|\n)${_keywords_match}=" "\\1_\\2=" _src_data "${_src_data}" )
+ string( REGEX REPLACE "(^|\n)${_keywords_match}[ ]*=[ ]*" "\\1_\\2=" _src_data "${_src_data}" )
file( WRITE ${CMAKE_CURRENT_BINARY_DIR}/${_out_name}.in "${_src_data}" )
# merge translations command
@@ -1749,19 +1749,18 @@ macro( tde_create_translated_desktop )
# merge translations target
add_custom_target( "${_target}" ALL DEPENDS ${_out_name} )
- install( FILES ${CMAKE_CURRENT_BINARY_DIR}/${_out_name} DESTINATION ${_dest} )
else( )
- # just install the original file without translations
- install(
- FILES ${CMAKE_CURRENT_SOURCE_DIR}/${_src}
- RENAME ${_out_name}
- DESTINATION ${_dest}
- )
+ # just write the original file without translations
+ file( READ ${_src} _src_data )
+ file( WRITE ${CMAKE_CURRENT_BINARY_DIR}/${_out_name} "${_src_data}" )
endif( )
+ # install traslated desktop file
+ install( FILES ${CMAKE_CURRENT_BINARY_DIR}/${_out_name} DESTINATION ${_dest} )
+
endmacro( )